%define libname libcurl

Name:          curl
Version:       8.9.1
Release:       1mamba
Summary:       A tool for transfering data with URL syntax that supports many protocols
Group:         Applications/Networking
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           https://curl.se/
Source:        http://curl.haxx.se/download/curl-%{version}.tar.bz2
License:       MIT
## AUTOBUILDREQ-BEGIN
BuildRequires: glibc-devel
BuildRequires: libbrotli-devel
BuildRequires: libcares-devel
BuildRequires: libgnutls-devel
BuildRequires: libgsasl-devel
BuildRequires: libgss-devel
BuildRequires: libidn2-devel
BuildRequires: libnettle-devel
BuildRequires: libnghttp2-devel
BuildRequires: libopenldap-devel
BuildRequires: libopenssl-devel
BuildRequires: libpsl-devel
BuildRequires: librtmp-devel
BuildRequires: libssh2-devel
BuildRequires: libz-devel
BuildRequires: libzstd-devel
## AUTOBUILDREQ-END
BuildRequires: pkgconfig
BuildRequires: libopenssl-devel >= 3.0.0
%if "%{stage1}" != "1"
BuildRequires: groff
%endif
BuildRequires: perl
Provides:      curl-gnutls
Obsoletes:     curl-gnutls < 7.82.0

# FIXME, not compiled in:
#  krb4 support:    no      (--with-krb4*)
#  SPNEGO support:  no      (--with-spnego)

# LDAPS support:   no      (--enable-ldaps)
#  SSPI support:    no      (--enable-sspi)
#  ca cert path:    no

%description
Curl is a tool for transfering data with URL syntax, supporting FTP, FTPS, HTTP, HTTPS, GOPHER, TELNET, DICT, FILE and LDAP.
This tool offer a myriad of powerful features and full protocol control.

%package -n %{libname}
Summary:       Dynamic Libraries for cURL
Group:         System/Libraries
%if "%{stage1}" != "1"
Requires:      ca-certificates
%endif

%description -n %{libname}
Libcurl is a library for transfering data with URL syntax, supporting FTP, FTPS, HTTP, HTTPS, GOPHER, TELNET, DICT, FILE and LDAP.
This library offer a myriad of powerful features and full protocol control.

%package -n %{libname}-gnutls
Summary:       Dynamic Libraries for cURL (linked against gnutls)
Group:         System/Libraries
%if "%{stage1}" != "1"
Requires:      ca-certificates
%endif

%description -n %{libname}-gnutls
Libcurl is a library for transfering data with URL syntax, supporting FTP, FTPS, HTTP, HTTPS, GOPHER, TELNET, DICT, FILE and LDAP.
This library offer a myriad of powerful features and full protocol control.

%package -n %{libname}-devel
Summary:       Static libraries and header for %{libname}
Group:         Development/Libraries
Requires:      %{libname} = %{?epoch:%epoch:}%{version}-%{release}
Requires:      %{libname}-gnutls = %{?epoch:%epoch:}%{version}-%{release}
Provides:      %{libname}-gnutls-devel
Obsoletes:     %{libname}-gnutls-devel < 7.82.0

%description -n %{libname}-devel
Curl is a tool and libcurl is a library for transfering data with URL syntax, supporting FTP, FTPS, HTTP, HTTPS, GOPHER, TELNET, DICT, FILE and LDAP.
The tool and library offer a myriad of powerful features and full protocol control.
This package contains static libraries and header files needed for development.

%debug_package

%prep
%setup -q
#-D -T
#:<< _EOF

mkdir gnutls
cd gnutls
cp -r ../* . || true

%build
#:<< _EOF
%configure \
   --enable-shared \
   --enable-static \
   --enable-cookies \
   --enable-crypto-auth \
   --enable-http \
   --enable-ftp \
   --enable-file \
   --enable-dict \
   --enable-telnet \
   --enable-tftp \
   --enable-ipv6 \
   --with-openssl \
   --with-zlib \
   --with-random \
   --enable-verbose \
   --disable-sspi \
   --with-libssh2 \
%if "%{stage1}" != "1"
   --with-gssapi \
   --enable-ldap \
   --with-libidn \
   --enable-manual \
   --with-ca-bundle=%{_sysconfdir}/pki/tls/certs/ca-bundle.crt \
%else
   --without-krb5 \
%endif
   --enable-ares

%make \
%if "%{_host}" != "%{_build}"
   CFLAGS="-lcares -lssh2"
%endif

cd gnutls
sed -i "s|libcurl\.la|libcurl-gnutls\.la|g" lib/Makefile.am
sed -i "s|libcurl_la|libcurl_gnutls_la|g" lib/Makefile.am
autoreconf -f -i

%configure \
   --enable-shared \
   --enable-static \
   --enable-cookies \
   --enable-crypto-auth \
   --enable-http \
   --enable-ftp \
   --enable-file \
   --enable-dict \
   --enable-telnet \
   --enable-tftp \
   --enable-ipv6 \
   --without-openssl \
   --with-gnutls \
   --with-zlib \
   --with-random \
   --enable-verbose \
   --disable-sspi \
   --with-libssh2 \
%if "%{stage1}" != "1"
   --with-gssapi \
   --enable-ldap \
   --with-libidn \
   --enable-manual \
   --with-ca-bundle=%{_sysconfdir}/pki/tls/certs/ca-bundle.crt \
%else
   --without-krb5 \
%endif
   --enable-ares

cd lib
%make

%install
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"

%makeinstall

cd gnutls/lib/
%makeinstall

%clean
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/curl
%{_mandir}/man1/curl.*

%files -n %{libname}
%defattr(-,root,root)
%{_libdir}/libcurl.so.*
%doc COPYING

%files -n %{libname}-gnutls
%defattr(-,root,root)
%{_libdir}/libcurl-gnutls.so.*
%doc COPYING

%files -n %{libname}-devel
%defattr(-,root,root)
%{_bindir}/curl-config
%{_includedir}/curl/
%{_libdir}/libcurl.a
%{_libdir}/libcurl.so
%{_libdir}/libcurl-gnutls.a
%{_libdir}/libcurl-gnutls.so
%{_libdir}/pkgconfig/libcurl.pc
%{_datadir}/aclocal/libcurl.m4
%{_mandir}/man1/curl-config.1*
%{_mandir}/man3/*
%doc docs/FAQ
%doc docs/KNOWN_BUGS docs/THANKS docs/TODO
%doc CHANGES README RELEASE-NOTES

%changelog
* Wed Jul 31 2024 Automatic Build System <autodist@openmamba.org> 8.9.1-1mamba
- automatic version update by autodist

* Thu Jul 25 2024 Automatic Build System <autodist@openmamba.org> 8.9.0-1mamba
- automatic version update by autodist

* Sun May 26 2024 Automatic Build System <autodist@openmamba.org> 8.8.0-1mamba
- automatic version update by autodist

* Fri Mar 29 2024 Automatic Build System <autodist@openmamba.org> 8.7.1-1mamba
- automatic version update by autodist

* Thu Feb 01 2024 Automatic Build System <autodist@openmamba.org> 8.6.0-1mamba
- automatic version update by autodist

* Thu Dec 07 2023 Automatic Build System <autodist@mambasoft.it> 8.5.0-1mamba
- automatic version update by autodist

* Wed Oct 11 2023 Automatic Build System <autodist@mambasoft.it> 8.4.0-1mamba
- automatic version update by autodist

* Wed Sep 13 2023 Automatic Build System <autodist@mambasoft.it> 8.3.0-1mamba
- automatic version update by autodist

* Wed Jul 26 2023 Automatic Build System <autodist@mambasoft.it> 8.2.1-1mamba
- automatic version update by autodist

* Wed Jul 19 2023 Automatic Build System <autodist@mambasoft.it> 8.2.0-1mamba
- automatic version update by autodist

* Tue May 30 2023 Automatic Build System <autodist@mambasoft.it> 8.1.2-1mamba
- automatic version update by autodist

* Tue May 23 2023 Automatic Build System <autodist@mambasoft.it> 8.1.1-1mamba
- automatic version update by autodist

* Wed May 17 2023 Automatic Build System <autodist@mambasoft.it> 8.1.0-1mamba
- automatic version update by autodist

* Mon Mar 20 2023 Automatic Build System <autodist@mambasoft.it> 8.0.1-1mamba
- automatic version update by autodist

* Mon Feb 20 2023 Automatic Build System <autodist@mambasoft.it> 7.88.1-1mamba
- automatic version update by autodist

* Wed Feb 15 2023 Automatic Build System <autodist@mambasoft.it> 7.88.0-1mamba
- automatic version update by autodist

* Wed Dec 21 2022 Automatic Build System <autodist@mambasoft.it> 7.87.0-1mamba
- automatic version update by autodist

* Fri Nov 11 2022 Automatic Build System <autodist@mambasoft.it> 7.86.0-1mamba
- automatic version update by autodist

* Fri Sep 02 2022 Automatic Build System <autodist@mambasoft.it> 7.85.0-1mamba
- automatic version update by autodist

* Mon Jun 27 2022 Automatic Build System <autodist@mambasoft.it> 7.84.0-1mamba
- automatic version update by autodist

* Thu May 12 2022 Automatic Build System <autodist@mambasoft.it> 7.83.1-1mamba
- automatic version update by autodist

* Wed Apr 27 2022 Automatic Build System <autodist@mambasoft.it> 7.83.0-1mamba
- automatic version update by autodist

* Sat Apr 02 2022 Automatic Build System <autodist@mambasoft.it> 7.82.0-1mamba
- automatic version update by autodist

* Wed Jan 05 2022 Automatic Build System <autodist@mambasoft.it> 7.81.0-1mamba
- automatic version update by autodist

* Wed Nov 10 2021 Automatic Build System <autodist@mambasoft.it> 7.80.0-1mamba
- automatic version update by autodist

* Thu Oct 21 2021 Silvan Calarco <silvan.calarco@mambasoft.it> 7.79.1-2mamba
- rebuilt with openssl 3.0.0

* Wed Sep 22 2021 Automatic Build System <autodist@mambasoft.it> 7.79.1-1mamba
- automatic version update by autodist

* Wed Sep 15 2021 Automatic Build System <autodist@mambasoft.it> 7.79.0-1mamba
- automatic version update by autodist

* Wed Jul 21 2021 Automatic Build System <autodist@mambasoft.it> 7.78.0-1mamba
- automatic version update by autodist

* Wed May 26 2021 Automatic Build System <autodist@mambasoft.it> 7.77.0-1mamba
- automatic version update by autodist

* Wed Apr 14 2021 Automatic Build System <autodist@mambasoft.it> 7.76.1-1mamba
- automatic version update by autodist

* Wed Mar 31 2021 Automatic Build System <autodist@mambasoft.it> 7.76.0-1mamba
- automatic version update by autodist

* Fri Feb 05 2021 Automatic Build System <autodist@mambasoft.it> 7.75.0-1mamba
- automatic version update by autodist

* Fri Dec 18 2020 Automatic Build System <autodist@mambasoft.it> 7.74.0-1mamba
- automatic version update by autodist

* Thu Oct 15 2020 Automatic Build System <autodist@mambasoft.it> 7.73.0-1mamba
- automatic version update by autodist

* Thu Aug 20 2020 Automatic Build System <autodist@mambasoft.it> 7.72.0-1mamba
- automatic version update by autodist

* Wed Jul 01 2020 Automatic Build System <autodist@mambasoft.it> 7.71.1-1mamba
- automatic version update by autodist

* Thu Jun 25 2020 Automatic Build System <autodist@mambasoft.it> 7.71.0-1mamba
- automatic version update by autodist

* Wed Apr 29 2020 Automatic Build System <autodist@mambasoft.it> 7.70.0-1mamba
- automatic version update by autodist

* Wed Mar 11 2020 Automatic Build System <autodist@mambasoft.it> 7.69.1-1mamba
- automatic version update by autodist

* Wed Mar 04 2020 Automatic Build System <autodist@mambasoft.it> 7.69.0-1mamba
- automatic version update by autodist

* Wed Jan 08 2020 Automatic Build System <autodist@mambasoft.it> 7.68.0-1mamba
- automatic version update by autodist

* Wed Nov 06 2019 Automatic Build System <autodist@mambasoft.it> 7.67.0-1mamba
- automatic version update by autodist

* Wed Sep 11 2019 Automatic Build System <autodist@mambasoft.it> 7.66.0-1mamba
- automatic version update by autodist

* Fri Jul 19 2019 Automatic Build System <autodist@mambasoft.it> 7.65.3-1mamba
- automatic version update by autodist

* Wed Jul 17 2019 Automatic Build System <autodist@mambasoft.it> 7.65.2-1mamba
- automatic version update by autodist

* Wed Jun 05 2019 Automatic Build System <autodist@mambasoft.it> 7.65.1-1mamba
- automatic version update by autodist

* Wed May 22 2019 Automatic Build System <autodist@mambasoft.it> 7.65.0-1mamba
- automatic version update by autodist

* Sun Mar 31 2019 Automatic Build System <autodist@mambasoft.it> 7.64.1-1mamba
- automatic version update by autodist

* Wed Feb 06 2019 Automatic Build System <autodist@mambasoft.it> 7.64.0-1mamba
- automatic version update by autodist

* Wed Dec 12 2018 Automatic Build System <autodist@mambasoft.it> 7.63.0-1mamba
- automatic version update by autodist

* Fri Nov 02 2018 Automatic Build System <autodist@mambasoft.it> 7.62.0-1mamba
- automatic version update by autodist

* Wed Sep 05 2018 Automatic Build System <autodist@mambasoft.it> 7.61.1-1mamba
- automatic version update by autodist

* Wed Jul 11 2018 Automatic Build System <autodist@mambasoft.it> 7.61.0-1mamba
- automatic version update by autodist

* Wed May 16 2018 Automatic Build System <autodist@mambasoft.it> 7.60.0-1mamba
- automatic version update by autodist

* Wed Mar 14 2018 Automatic Build System <autodist@mambasoft.it> 7.59.0-1mamba
- automatic version update by autodist

* Wed Jan 24 2018 Automatic Build System <autodist@mambasoft.it> 7.58.0-1mamba
- automatic version update by autodist

* Wed Dec 20 2017 Automatic Build System <autodist@mambasoft.it> 7.57.0-1mamba
- automatic update by autodist

* Wed Nov 01 2017 Silvan Calarco <silvan.calarco@mambasoft.it> 7.56.1-2mamba
- rebuilt without --with-nss to have libcurl package linked against openssl (with-ssl)

* Sun Oct 29 2017 Automatic Build System <autodist@mambasoft.it> 7.56.1-1mamba
- automatic version update by autodist

* Thu Oct 05 2017 Automatic Build System <autodist@mambasoft.it> 7.56.0-1mamba
- automatic version update by autodist

* Wed Aug 30 2017 Silvan Calarco <silvan.calarco@mambasoft.it> 7.55.1-3mamba
- hack to fix libcurl-gnutls soname

* Tue Aug 29 2017 Silvan Calarco <silvan.calarco@mambasoft.it> 7.55.1-2mamba
- build and provide libcurl-gnutls

* Wed Aug 16 2017 Automatic Build System <autodist@mambasoft.it> 7.55.1-1mamba
- automatic version update by autodist

* Thu Jun 15 2017 Automatic Build System <autodist@mambasoft.it> 7.54.1-1mamba
- automatic version update by autodist

* Mon Apr 24 2017 Automatic Build System <autodist@mambasoft.it> 7.54.0-1mamba
- automatic version update by autodist

* Mon Feb 27 2017 Automatic Build System <autodist@mambasoft.it> 7.53.1-1mamba
- automatic version update by autodist

* Mon Dec 26 2016 Automatic Build System <autodist@mambasoft.it> 7.52.1-1mamba
- automatic version update by autodist

* Wed Nov 02 2016 Automatic Build System <autodist@mambasoft.it> 7.51.0-1mamba
- automatic version update by autodist

* Wed Sep 14 2016 Automatic Build System <autodist@mambasoft.it> 7.50.3-1mamba
- automatic version update by autodist

* Fri Sep 09 2016 Automatic Build System <autodist@mambasoft.it> 7.50.2-1mamba
- automatic version update by autodist

* Wed Aug 03 2016 Automatic Build System <autodist@mambasoft.it> 7.50.1-1mamba
- automatic version update by autodist

* Thu Jul 21 2016 Automatic Build System <autodist@mambasoft.it> 7.50.0-1mamba
- automatic version update by autodist

* Mon May 30 2016 Automatic Build System <autodist@mambasoft.it> 7.49.1-1mamba
- automatic version update by autodist

* Fri May 20 2016 Automatic Build System <autodist@mambasoft.it> 7.49.0-1mamba
- automatic version update by autodist

* Tue May 03 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 7.48.0-2mamba
- rebuilt with openssl 1.0.2

* Wed Mar 23 2016 Automatic Build System <autodist@mambasoft.it> 7.48.0-1mamba
- automatic version update by autodist

* Mon Feb 08 2016 Automatic Build System <autodist@mambasoft.it> 7.47.1-1mamba
- automatic version update by autodist

* Wed Jan 27 2016 Automatic Build System <autodist@mambasoft.it> 7.47.0-1mamba
- automatic version update by autodist

* Thu Dec 03 2015 Automatic Build System <autodist@mambasoft.it> 7.46.0-1mamba
- automatic version update by autodist

* Wed Oct 07 2015 Automatic Build System <autodist@mambasoft.it> 7.45.0-1mamba
- automatic version update by autodist

* Wed Aug 12 2015 Automatic Build System <autodist@mambasoft.it> 7.44.0-1mamba
- automatic version update by autodist

* Wed Jun 17 2015 Automatic Build System <autodist@mambasoft.it> 7.43.0-1mamba
- automatic version update by autodist

* Wed Apr 29 2015 Automatic Build System <autodist@mambasoft.it> 7.42.1-1mamba
- automatic version update by autodist

* Fri Apr 24 2015 Automatic Build System <autodist@mambasoft.it> 7.42.0-1mamba
- automatic version update by autodist

* Sun Mar 15 2015 Automatic Build System <autodist@mambasoft.it> 7.41.0-1mamba
- automatic version update by autodist

* Wed Jan 21 2015 Automatic Build System <autodist@mambasoft.it> 7.40.0-1mamba
- automatic version update by autodist

* Wed Nov 05 2014 Automatic Build System <autodist@mambasoft.it> 7.39.0-1mamba
- automatic version update by autodist

* Wed Sep 10 2014 Automatic Build System <autodist@mambasoft.it> 7.38.0-1mamba
- automatic version update by autodist

* Thu Jul 17 2014 Automatic Build System <autodist@mambasoft.it> 7.37.1-1mamba
- automatic version update by autodist

* Wed May 21 2014 Automatic Build System <autodist@mambasoft.it> 7.37.0-1mamba
- automatic version update by autodist

* Wed Mar 26 2014 Automatic Build System <autodist@mambasoft.it> 7.36.0-1mamba
- automatic version update by autodist

* Wed Jan 29 2014 Automatic Build System <autodist@mambasoft.it> 7.35.0-1mamba
- automatic version update by autodist

* Wed Dec 25 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 7.34.0-2mamba
- repatched to prefer ipv4 address resolution

* Wed Dec 18 2013 Automatic Build System <autodist@mambasoft.it> 7.34.0-1mamba
- automatic version update by autodist

* Tue Oct 15 2013 Automatic Build System <autodist@mambasoft.it> 7.33.0-1mamba
- automatic version update by autodist

* Mon Aug 12 2013 Automatic Build System <autodist@mambasoft.it> 7.32.0-1mamba
- automatic version update by autodist

* Sat Jun 22 2013 Automatic Build System <autodist@mambasoft.it> 7.31.0-1mamba
- automatic version update by autodist

* Fri Apr 12 2013 Automatic Build System <autodist@mambasoft.it> 7.30.0-1mamba
- automatic version update by autodist

* Wed Feb 06 2013 Automatic Build System <autodist@mambasoft.it> 7.29.0-1mamba
- automatic version update by autodist

* Tue Nov 20 2012 Automatic Build System <autodist@mambasoft.it> 7.28.1-1mamba
- update to 7.28.1

* Thu Oct 11 2012 Automatic Build System <autodist@mambasoft.it> 7.28.0-1mamba
- automatic version update by autodist

* Sat Jul 28 2012 Automatic Build System <autodist@mambasoft.it> 7.27.0-1mamba
- automatic version update by autodist

* Wed Jun 06 2012 Automatic Build System <autodist@mambasoft.it> 7.26.0-1mamba
- automatic version update by autodist

* Fri Mar 23 2012 Automatic Build System <autodist@mambasoft.it> 7.25.0-1mamba
- automatic version update by autodist

* Thu Jan 26 2012 Automatic Build System <autodist@mambasoft.it> 7.24.0-1mamba
- automatic version update by autodist

* Fri Nov 18 2011 Automatic Build System <autodist@mambasoft.it> 7.23.1-1mamba
- automatic version update by autodist

* Wed Nov 16 2011 Automatic Build System <autodist@mambasoft.it> 7.23.0-1mamba
- automatic version update by autodist

* Wed Sep 14 2011 Automatic Build System <autodist@mambasoft.it> 7.22.0-1mamba
- automatic version update by autodist

* Thu Jun 23 2011 Automatic Build System <autodist@mambasoft.it> 7.21.7-1mamba
- automatic update by autodist

* Sun Apr 24 2011 Davide Madrisan <davide.madrisan@gmail.com> 7.21.6-1mamba
- update to 7.21.6

* Mon Apr 18 2011 Automatic Build System <autodist@mambasoft.it> 7.21.5-1mamba
- automatic update by autodist

* Sat Mar 05 2011 Automatic Build System <autodist@mambasoft.it> 7.21.4-1mamba
- automatic update by autodist

* Thu Oct 14 2010 Davide Madrisan <davide.madrisan@gmail.com> 7.21.2-1mamba
- update to 7.21.2

* Wed Jun 16 2010 Automatic Build System <autodist@mambasoft.it> 7.21.0-1mamba
- automatic update to 7.21.0 by autodist

* Fri May 28 2010 Automatic Build System <autodist@mambasoft.it> 7.20.1-1mamba
- automatic update to 7.20.1 by autodist

* Tue Feb 09 2010 Automatic Build System <autodist@mambasoft.it> 7.20.0-1mamba
- automatic update to 7.20.0 by autodist

* Wed Nov 04 2009 Automatic Build System <autodist@mambasoft.it> 7.19.7-1mamba
- automatic update to 7.19.7 by autodist

* Thu Aug 13 2009 Automatic Build System <autodist@mambasoft.it> 7.19.6-1mamba
- automatic update to 7.19.6 by autodist

* Mon May 18 2009 Automatic Build System <autodist@mambasoft.it> 7.19.5-1mamba
- automatic update to 7.19.5 by autodist

* Tue Mar 03 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 7.19.4-1mamba
- automatic update to 7.19.4 by autodist

* Wed Jan 21 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 7.19.3-1mamba
- automatic update to 7.19.3 by autodist

* Fri Nov 14 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 7.19.2-1mamba
- automatic update to 7.19.2 by autodist

* Wed Nov 12 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 7.19.1-1mamba
- automatic update to 7.19.1 by autodist

* Tue Oct 14 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 7.19.0-2mamba
- enabled static library build as required by pycurl
- added a patch that enables ipv4 search by default insted of ipv6; use -6 to force ipv6 lookups

* Sun Oct 12 2008 gil <puntogil@libero.it> 7.19.0-1mamba
- update to 7.19.0 

* Fri Aug 29 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 7.18.2-1mamba
- update to 7.18.2

* Thu Jun 05 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 7.18.1-2mamba
- added build of curl-gnutls packages

* Tue Jun 03 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 7.18.1-1mamba
- update to 7.18.1

* Tue Nov 20 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 7.17.1-1mamba
- update to 7.17.1
- rebuild with c-ares support (async DNS queries)

* Sun Oct 14 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 7.17.0-1mamba
- update to 7.17.0

* Thu Jul 12 2007 Aleph0 <aleph0@openmamba.org> 7.16.4-2mamba
- add all the available documentation for developers to the devel subpackage

* Wed Jul 11 2007 Aleph0 <aleph0@openmamba.org> 7.16.4-1mamba
- update to 7.16.4

* Thu Apr 12 2007 Davide Madrisan <davide.madrisan@gmail.com> 7.16.2-2mamba
- esnabled LIBSSH2 support

* Thu Apr 12 2007 Davide Madrisan <davide.madrisan@gmail.com> 7.16.2-1mamba
- update to version 7.16.2 by autospec
- do not build the static library
- enabled GSSAPI support

* Mon Apr 02 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 7.16.1-1mamba
- update to version 7.16.1 by autospec

* Tue Jun 13 2006 Davide Madrisan <davide.madrisan@qilinux.it> 7.15.4-1qilnx
- update to version 7.15.4 by autospec

* Mon Mar 20 2006 Davide Madrisan <davide.madrisan@qilinux.it> 7.15.3-1qilnx
- update to version 7.15.3 by autospec
- also fixes the TFTP packet buffer overflow vulnerability

* Thu Mar 02 2006 Davide Madrisan <davide.madrisan@qilinux.it> 7.15.2-1qilnx
- update to version 7.15.2 by autospec

* Wed Dec 07 2005 Davide Madrisan <davide.madrisan@qilinux.it> 7.15.1-1qilnx
- update to version 7.15.1 by autospec

* Mon Oct 17 2005 Davide Madrisan <davide.madrisan@qilinux.it> 7.15.0-1qilnx
- update to version 7.15.0 by autospec
- also fixes the security issue QSA-2005-120 (CAN-2005-3185)

* Sun Oct 02 2005 Davide Madrisan <davide.madrisan@qilinux.it> 7.14.1-2qilnx
- new package curl
- curl-config manpage moved to devel package
- own %{_datadir}/curl and %{_includedir}/curl

* Wed Sep 07 2005 Davide Madrisan <davide.madrisan@qilinux.it> 7.14.1-1qilnx
- update to version 7.14.1 by autospec

* Mon Mar 07 2005 Davide Madrisan <davide.madrisan@qilinux.it> 7.13.1-1qilnx
- update to version 7.13.1 by autospec
- also include security fix (CAN-2005-0490)
- added missing build requirement: libidn-devel, libkrb5-devel

* Mon Jul 26 2004 Davide Madrisan <davide.madrisan@qilinux.it> 7.12.0-1qilnx
- first build
